@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# cvm调用失败。
+INTERNALERROR_CALLCVM = 'InternalError.CallCvm'
+
 # 参数格式有误。
 INVALIDPARAMETER_MALFORMED = 'InvalidParameter.Malformed'
 
